import ZVToken from '../src'
import { randomBytes } from 'node:crypto'
import { describe, it, expect } from 'bun:test'

const zv = new ZVToken({
    secret: randomBytes(8).toString('hex'),
    structures: ['user_id', 'session_id']
})

describe('zv-token', () => {
    let token: string,
        gotPayload: Record<string, any>

    const payload = {
        user_id: 123,
        session_id: 123
    }

    it('should make token', () => {
        token = zv.sign(payload)
        expect(token).toMatch(/^zv\.[\w-]+\.[\w-]+$/)
    })

    it('should verify token', () => {
        const data = zv.verify(token)
        expect(data.status).toBeTrue()
        gotPayload = data.payload!
    })

    it('should get correct payload', () => {
        expect(gotPayload.user_id).toBe(payload.user_id)
    })
})